@@ -140,7 +140,7 @@ class ASGIRequestResponseBridge:
 
     def __str__(self) -> str:
         return f"ASGIRequestResponseBridge({self.app!r}, {self.dispatch_func!r})"
-    
+
     async def __call__(self, scope: Scope, receive: Receive, send: Send) -> None:
         if scope["type"] != "http":
             await self.app(scope, receive, send)
@@ -148,13 +148,12 @@ class ASGIRequestResponseBridge:
 
         request = _CachedRequest(scope, receive)
         response = Response(request=request)
-
         wrapped_receive = request.wrapped_receive
         response_sent = anyio.Event()
 
         async def call_next(
             *_,
-        ) -> Response:  # Why cant this be flexible , i mean ☺️🤷‍♀️
+        ) -> Response:
             app_exc: Exception | None = None
 
             async def receive_or_disconnect() -> Message:
@@ -200,12 +199,15 @@ class ASGIRequestResponseBridge:
                     raise app_exc
                 raise RuntimeError("Client disconnected before response was sent")
             assert message["type"] == "http.response.start"
+            buffered_body = b""
 
             async def body_stream() -> typing.AsyncGenerator[bytes, None]:
+                nonlocal buffered_body
                 async for message in recv_stream:
                     assert message["type"] == "http.response.body"
                     body = message.get("body", b"")
                     if body:
+                        buffered_body += body
                         yield body
                     if not message.get("more_body", False):
                         break
@@ -213,14 +215,15 @@ class ASGIRequestResponseBridge:
                     raise app_exc
 
             response_ = response.stream(
-                iterator=body_stream(), status_code=message["status"]
+                iterator=body_stream(),
+                status_code=message["status"],  # type: ignore
             )  # type: ignore
             response_._response._headers = message["headers"]  # type: ignore
-            return response
+            return response_._response  # type:ignore
 
-        streams: anyio.create_memory_object_stream[Message] = (
+        streams: anyio.create_memory_object_stream[Message] = (  # type: ignore
             anyio.create_memory_object_stream()
-        )  # type: ignore
+        )
         send_stream, recv_stream = streams
         with recv_stream, send_stream, collapse_excgroups():
             async with anyio.create_task_group() as task_group:
