@@ -1,4 +1,3 @@
-import re
 from typing import (
     Any,
     AsyncContextManager,
@@ -6,11 +5,12 @@ from typing import (
     Callable,
     Dict,
     List,
+    Literal,
     Optional,
     Type,
     Union,
+    TYPE_CHECKING
 )
-from typing import Literal
 
 from pydantic import BaseModel
 from typing_extensions import Annotated, Doc
@@ -20,6 +20,7 @@ from nexios._internals._middleware import (
 )
 from nexios._internals._middleware import DefineMiddleware as Middleware
 from nexios.config import DEFAULT_CONFIG, MakeConfig
+from nexios.dependencies import Depend
 from nexios.events import AsyncEventEmitter
 from nexios.exception_handler import ExceptionHandlerType, ExceptionMiddleware
 from nexios.logging import create_logger
@@ -29,11 +30,11 @@ from nexios.middleware.errors.server_error_handler import (
 )
 from nexios.openapi._builder import APIDocumentation
 from nexios.openapi.config import OpenAPIConfig
-from nexios.openapi.models import HTTPBearer, Parameter, Path, Schema
+from nexios.openapi.models import HTTPBearer, Parameter
 from nexios.routing.base import BaseRoute
 from nexios.structs import URLPath
 
-from .routing import Router, Routes, WebsocketRoutes, WSRouter
+from .routing import Router, Route, WebsocketRoute, WSRouter
 from .types import (
     ASGIApp,
     HandlerType,
@@ -45,7 +46,8 @@ from .types import (
     WsHandlerType,
     WsMiddlewareType,
 )
-
+if TYPE_CHECKING:
+    from nexios.http import Request,Response
 allowed_methods_default = ["get", "post", "delete", "put", "patch", "options"]
 
 logger = create_logger("nexios")
@@ -99,8 +101,8 @@ class NexiosApp(object):
             ),
         ] = None,
         lifespan: Optional[lifespan_manager] = None,
-        routes: Optional[List[Routes]] = None,
-        dependencies: Optional[list] = None,
+        routes: Optional[List[Route]] = None,
+        dependencies: Optional[list[Depend]] = None,
     ):
         self.config = config or DEFAULT_CONFIG
         self.dependencies = dependencies or []
@@ -108,7 +110,7 @@ class NexiosApp(object):
             from nexios.cli.utils import get_config as get_nexios_config
         except ImportError:
 
-            def get_nexios_config():
+            def get_nexios_config() -> Dict[str, Any]:
                 return {}
 
         from nexios.config import get_config, set_config
@@ -121,20 +123,20 @@ class NexiosApp(object):
             get_nexios_config(),
         )
         self.ws_router = WSRouter()
-        self.ws_routes: List[WebsocketRoutes] = []
+        self.ws_routes: List[WebsocketRoute] = []
         self.http_middleware: List[Middleware] = []
         self.ws_middleware: List[ASGIApp] = []
         self.startup_handlers: List[Callable[[], Awaitable[None]]] = []
         self.shutdown_handlers: List[Callable[[], Awaitable[None]]] = []
-        self.exceptions_handler = ExceptionMiddleware()
         self.server_error_handler = server_error_handler
-        self._background_tasks = set()
+        self._background_tasks = set()  # type:ignore
 
         self.app = Router(routes=routes, dependencies=self.dependencies)  # type:ignore
+        self.exceptions_handler = ExceptionMiddleware()
         self.router = self.app
         self.route = self.router.route
         self.lifespan_context: Optional[lifespan_manager] = lifespan
-        self.state = {}
+        self.state: Dict[str, Any] = {}
 
         openapi_config: Dict[str, Any] = self.config.to_dict().get("openapi", {})  # type:ignore
         self.openapi_config = OpenAPIConfig(
@@ -151,8 +153,7 @@ class NexiosApp(object):
             "bearerAuth", HTTPBearer(type="http", scheme="bearer", bearerFormat="JWT")
         )
 
-        self.docs = APIDocumentation(
-            app=self,
+        self.openapi = APIDocumentation(
             config=self.openapi_config,
             swagger_url=openapi_config.get("swagger_url", "/docs"),
             redoc_url=openapi_config.get("redoc_url", "/redoc"),
@@ -161,6 +162,28 @@ class NexiosApp(object):
 
         self.events = AsyncEventEmitter()
         self.title = title or "Nexios API"
+        self.setup()
+
+    def setup(self):
+        
+        @self.get(self.openapi.openapi_url, exclude_from_schema=True)  # type:ignore
+        async def serve_openapi(request: "Request", response: "Response"):
+            root_path = request.scope.get("root_path", "")
+            return response.json(self.openapi.get_openapi(self.router,current_prefix=root_path))
+
+        @self.get(self.openapi.swagger_url, exclude_from_schema=True)  # type:ignore
+        async def swagger_ui(request: "Request", response: "Response"):
+            # Get the current mount path from the request scope
+            root_path = request.scope.get("root_path", "")
+            openapi_url = root_path + self.openapi.openapi_url
+            return response.html(self.openapi._generate_swagger_ui(openapi_url))
+
+        @self.get(self.openapi.redoc_url, exclude_from_schema=True)  # type:ignore
+        async def redoc_ui(request: "Request", response: "Response"):
+            # Get the current mount path from the request scope
+            root_path = request.scope.get("root_path", "")
+            openapi_url = root_path + self.openapi.openapi_url
+            return response.html(self.openapi._generate_redoc_ui(openapi_url))
 
     def on_startup(self, handler: Callable[[], Awaitable[None]]) -> None:
         """
@@ -267,7 +290,7 @@ class NexiosApp(object):
 
     async def handle_lifespan(self, receive: Receive, send: Send) -> None:
         """Handle ASGI lifespan protocol events."""
-        self._setup_openapi()
+        # self._setup_openapi()
         try:
             while True:
                 message: Message = await receive()
@@ -312,34 +335,6 @@ class NexiosApp(object):
             else:
                 await send({"type": "lifespan.shutdown.failed", "message": str(e)})
 
-    def _setup_openapi(self) -> None:
-        """Set up automatic OpenAPI documentation"""
-        docs = self.docs
-
-        for route in self.get_all_routes():
-            if getattr(route, "exclude_from_schema", False):
-                continue
-            for method in route.methods:
-                parameters = [
-                    Path(name=x, schema=Schema(type="string"), schema_=None)  # type: ignore
-                    for x in route.param_names
-                ]
-                parameters.extend(route.parameters)  # type: ignore
-                docs.document_endpoint(
-                    path=re.sub(r"\{(\w+):\w+\}", r"{\1}", route.raw_path),
-                    method=method,
-                    tags=route.tags,
-                    security=route.security,
-                    summary=route.summary or "",
-                    description=route.description,
-                    request_body=route.request_model,
-                    request_content_type=getattr(route, "request_content_type", "application/json"),
-                    parameters=parameters,  # type:ignore
-                    deprecated=route.deprecated,
-                    operation_id=route.operation_id,
-                    responses=route.responses,
-                )(route.handler)
-
     def add_middleware(
         self,
         middleware: Annotated[
@@ -382,8 +377,8 @@ class NexiosApp(object):
         self,
         route: Optional[
             Annotated[
-                WebsocketRoutes,
-                Doc("An instance of the Routes class representing a WebSocket route."),
+                WebsocketRoute,
+                Doc("An instance of the Route class representing a WebSocket route."),
             ]
         ] = None,
         path: Optional[str] = None,
@@ -396,27 +391,37 @@ class NexiosApp(object):
         This method registers a WebSocket route, allowing the application to handle WebSocket connections.
 
         Args:
-            route (Routes): The WebSocket route configuration.
+            route (Route): The WebSocket route configuration.
 
         Returns:
             None
 
         Example:
             ```python
-            route = Routes("/ws/chat", chat_handler)
+            route = Route("/ws/chat", chat_handler)
             app.add_ws_route(route)
             ```
         """
+
         if route:
-            self.ws_router.add_ws_route(route)
-        else:
-            self.ws_router.add_ws_route(
-                WebsocketRoutes(path, handler, middleware=middleware)
+            if (not path or path == route.raw_path) and (
+                not handler or handler == route.handler
+            ):
+                self.ws_router.add_ws_route(route)
+                return
+
+        if path is None or handler is None:
+            raise ValueError(
+                "path and handler are required when 'route' is not provided."
             )
 
-    def mount_router(self, router: Router, path: Optional[str] = None) -> None:
+        self.ws_router.add_ws_route(
+            WebsocketRoute(path, handler, middleware=middleware)
+        )
+
+    def mount_router(self, router: Router, name: Optional[str] = None) -> None:
         """
-        Mounts a router and all its routes to the application.
+        Mounts a router and all its routes to the application using the router's prefix.
 
         This method allows integrating another `Router` instance, registering all its
         defined routes into the current application. It is useful for modularizing routes
@@ -430,16 +435,16 @@ class NexiosApp(object):
 
         Example:
             ```python
-            user_router = Router()
+            user_router = Router(prefix="/users")
 
-            @user_router.route("/users", methods=["GET"])
+            @user_router.route("/list", methods=["GET"])
             def get_users(request, response):
                  response.json({"users": ["Alice", "Bob"]})
 
             app.mount_router(user_router)  # Mounts the user routes into the main app
             ```
         """
-        self.router.mount_router(router, path=path)
+        self.router.mount_router(router, name=name)
 
     def mount_ws_router(
         self,
@@ -449,27 +454,27 @@ class NexiosApp(object):
         ],
     ) -> None:
         """
-        Mounts a router and all its routes to the application.
+        Mounts a websocket router and all its routes to the application using the router's prefix.
 
-        This method allows integrating another `Router` instance, registering all its
+        This method allows integrating another `WSRouter` instance, registering all its
         defined routes into the current application. It is useful for modularizing routes
         and organizing large applications.
 
         Args:
-            router (Router): The `Router` instance whose routes will be added.
+            router (WSRouter): The `WSRouter` instance whose routes will be added.
 
         Returns:
             None
 
         Example:
             ```python
-            chat_router = WSRouter()
+            chat_router = WSRouter(prefix="/chat")
 
-            @chat_router.ws("/users")
+            @chat_router.ws("/room")
             def get_users(ws):
                 ...
 
-            app.mount_ws_router(chat_router)  # Mounts the user routes into the main app
+            app.mount_ws_router(chat_router)  # Mounts the websocket routes into the main app
             ```
         """
         self.ws_router.mount_router(router)
@@ -749,6 +754,7 @@ class NexiosApp(object):
             description=description,
             responses=responses,
             request_model=request_model,
+            request_content_type="application/json",
             middleware=middleware,
             tags=tags,
             security=security,
@@ -836,8 +842,14 @@ class NexiosApp(object):
             ),
         ] = None,
         request_content_type: Annotated[
-            Literal["application/json", "multipart/form-data", "application/x-www-form-urlencoded"],
-            Doc("Content type for the request body in OpenAPI docs. Defaults to 'application/json'."),
+            Literal[
+                "application/json",
+                "multipart/form-data",
+                "application/x-www-form-urlencoded",
+            ],
+            Doc(
+                "Content type for the request body in OpenAPI docs. Defaults to 'application/json'."
+            ),
         ] = "application/json",
         middleware: Annotated[
             List[Any],
@@ -1157,6 +1169,7 @@ class NexiosApp(object):
             deprecated=deprecated,
             parameters=parameters,
             exclude_from_schema=exclude_from_schema,
+            request_content_type="application/json",
             **kwargs,
         )
 
@@ -1299,7 +1312,11 @@ class NexiosApp(object):
             ),
         ] = False,
         request_content_type: Annotated[
-            Optional[Literal["application/json", "application/x-www-form-urlencoded", "multipart/form-data"]],
+            Literal[
+                "application/json",
+                "application/x-www-form-urlencoded",
+                "multipart/form-data",
+            ],
             Doc(
                 """
                 Request content type.
@@ -1510,8 +1527,12 @@ class NexiosApp(object):
             """
             ),
         ] = False,
-         request_content_type: Annotated[
-            Optional[Literal["application/json", "application/x-www-form-urlencoded", "multipart/form-data"]],
+        request_content_type: Annotated[
+            Literal[
+                "application/json",
+                "application/x-www-form-urlencoded",
+                "multipart/form-data",
+            ],
             Doc(
                 """
                 Request content type.
@@ -1774,6 +1795,7 @@ class NexiosApp(object):
             deprecated=deprecated,
             parameters=parameters,
             exclude_from_schema=exclude_from_schema,
+            request_content_type="application/json",
             **kwargs,
         )
 
@@ -1960,6 +1982,7 @@ class NexiosApp(object):
             description=description,
             responses=responses,
             request_model=request_model,
+            request_content_type="application/json",
             middleware=middleware,
             tags=tags,
             security=security,
@@ -1973,8 +1996,8 @@ class NexiosApp(object):
     def add_route(
         self,
         route: Annotated[
-            Optional[Union[Routes, type[BaseRoute]]],
-            Doc("An instance of the Routes class representing an HTTP route."),
+            Optional[Union[Route, type[BaseRoute]]],
+            Doc("An instance of the Route class representing an HTTP route."),
         ] = None,
         path: Annotated[
             Optional[str],
@@ -2057,6 +2080,19 @@ class NexiosApp(object):
             """
             ),
         ] = None,
+        request_content_type: Annotated[
+            Literal[
+                "application/json",
+                "application/x-www-form-urlencoded",
+                "multipart/form-data",
+            ],
+            Doc(
+                """
+                Request content type.
+                Example: 'application/json'
+            """
+            ),
+        ] = "application/json",
         middleware: Annotated[
             List[Any],
             Doc(
@@ -2136,14 +2172,14 @@ class NexiosApp(object):
         This method registers an HTTP route, allowing the application to handle requests for a specific URL path.
 
         Args:
-            route (Routes): The HTTP route configuration.
+            route (Route): The HTTP route configuration.
 
         Returns:
             None
 
         Example:
             ```python
-            route = Routes("/home", home_handler, methods=["GET", "POST"])
+            route = Route("/home", home_handler, methods=["GET", "POST"])
             app.add_route(route)
             ```
         """
@@ -2152,7 +2188,7 @@ class NexiosApp(object):
                 raise ValueError(
                     "path and handler are required if route is not provided"
                 )
-            route = Routes(
+            route = Route(
                 path=path,
                 handler=handler,
                 methods=methods,
@@ -2161,6 +2197,7 @@ class NexiosApp(object):
                 description=description,
                 responses=responses,
                 request_model=request_model,
+                request_content_type=request_content_type,
                 middleware=middleware,
                 tags=tags,
                 security=security,
@@ -2192,7 +2229,7 @@ class NexiosApp(object):
                 exc_class_or_status_code, handler
             )
 
-    def url_for(self, _name: str, **path_params: Dict[str, Any]) -> URLPath:
+    def url_for(self, _name: str, **path_params: Any) -> URLPath:
         return self.router.url_for(_name, **path_params)
 
     def wrap_asgi(
@@ -2224,14 +2261,14 @@ class NexiosApp(object):
         self.app = middleware_cls(self.app, **kwargs)
         return None
 
-    def get_all_routes(self) -> List[Routes]:
+    def get_all_routes(self) -> List[Route]:
         """
         Returns all routes registered in the application.
 
         This method retrieves a list of all HTTP and WebSocket routes defined in the application.
 
         Returns:
-            List[Routes]: A list of all registered routes.
+            List[Route]: A list of all registered routes.
 
         Example:
             ```python
@@ -2296,7 +2333,6 @@ class NexiosApp(object):
         host: str = "127.0.0.1",
         port: int = 8000,
         reload: bool = False,
-        **kwargs,
     ):
         """
         Run the application using uvicorn.
@@ -2327,7 +2363,7 @@ class NexiosApp(object):
             import uvicorn
 
             print(f"Starting server with uvicorn: {host}:{port}")
-            uvicorn.run(self, host=host, port=port, reload=reload, **kwargs)
+            uvicorn.run(self, host=host, port=port, reload=reload)
         except ImportError:
             raise RuntimeError(
                 "uvicorn not found. Install it with: pip install uvicorn\n"
