@@ -1,7 +1,9 @@
 from .backends.apikey import APIKeyAuthBackend
 from .backends.jwt import JWTAuthBackend, create_jwt, decode_jwt
-from .decorator import auth
+from .decorator import auth, has_permission
 from .middleware import AuthenticationMiddleware
+from .users.base import BaseUser
+from .users.simple import SimpleUser
 
 __all__ = [
     "AuthenticationMiddleware",
@@ -10,4 +12,7 @@ __all__ = [
     "create_jwt",
     "decode_jwt",
     "auth",
+    "has_permission",
+    "BaseUser",
+    "SimpleUser",
 ]
