@@ -1,10 +1,32 @@
-from typing import Any, Awaitable, Callable
+import hashlib
+import secrets
+from typing import Any
 
 from typing_extensions import Annotated, Doc
 
-from nexios.auth.base import AuthenticationBackend, UnauthenticatedUser
+from nexios.auth.base import AuthenticationBackend
+from nexios.auth.model import AuthResult
 from nexios.http import Request, Response
 
+prefix = "key"
+
+
+def create_api_key() -> tuple[str, str]:
+    raw_token = secrets.token_urlsafe(32)
+
+    api_key = f"{prefix}_{raw_token}"
+
+    hashed = hashlib.sha256(api_key.encode()).hexdigest()
+    return api_key, hashed
+
+
+def verify_key(api_key: str, stored_hash: str) -> bool:
+    """
+    Verify an incoming API key against a stored hash.
+    """
+    hashed_input = hashlib.sha256(api_key.encode()).hexdigest()
+    return secrets.compare_digest(hashed_input, stored_hash)
+
 
 class APIKeyAuthBackend(AuthenticationBackend):
     """
@@ -20,18 +42,16 @@ class APIKeyAuthBackend(AuthenticationBackend):
 
     def __init__(
         self,
-        authenticate_func: Annotated[
-            Callable[..., Awaitable[Any]],
-            Doc(
-                "Function that takes an API key and returns a user object if valid, None otherwise."
-            ),
-        ],
         header_name: Annotated[
             str,
             Doc(
                 'The header name from which the API key is retrieved (default: "X-API-Key").'
             ),
         ] = "X-API-Key",
+        prefix: Annotated[
+            str,
+            Doc('The prefix for the API key (default: "key").'),
+        ] = "key",
     ) -> None:
         """
         Initializes the APIKeyAuthBackend with an authentication function and optional header name.
@@ -40,8 +60,8 @@ class APIKeyAuthBackend(AuthenticationBackend):
             authenticate_func (Callable[..., Awaitable[Any]]): Function to validate API keys.
             header_name (str, optional): Header key where the API key is expected (default: "X-API-Key").
         """
-        self.authenticate_func = authenticate_func
         self.header_name = header_name
+        self.prefix = prefix
 
     async def authenticate(  # type: ignore[override]
         self,
@@ -75,14 +95,11 @@ class APIKeyAuthBackend(AuthenticationBackend):
             - If no API key is found, sets the `WWW-Authenticate` response header.
         """
         # Retrieve the API key from the request headers
-        api_key = request.headers.get(self.header_name)
-        if not api_key:
+        raw_token = request.headers.get(self.header_name)
+
+        if not raw_token:
             response.set_header("WWW-Authenticate", 'APIKey realm="Access to the API"')
-            return None
+            return AuthResult(success=False, identity="", scope="")
 
         # Authenticate the API key using the provided function
-        user = await self.authenticate_func(api_key)
-        if not user:
-            return UnauthenticatedUser()
-
-        return user, "apikey"
+        return AuthResult(success=True, identity=raw_token, scope="apikey")
