@@ -2,15 +2,21 @@ try:
     import jwt
 except ImportError:
     jwt = None
-from typing import Any, Callable, Dict, List, Optional
+from datetime import datetime, timedelta, timezone
+from typing import Any, Dict, List, Optional
 
-from nexios.auth.base import AuthenticationBackend, UnauthenticatedUser
+from nexios.auth.model import AuthResult
 from nexios.config import get_config
 from nexios.http import Request, Response
 
+from .base import AuthenticationBackend
+
 
 def create_jwt(
-    payload: Dict[str, Any], secret: Optional[str] = None, algorithm: str = "HS256"
+    payload: Dict[str, Any],
+    secret: Optional[str] = None,
+    algorithm: str = "HS256",
+    expires_in: Optional[timedelta] = None,
 ) -> str:
     """
     Create a JWT token.
@@ -23,7 +29,10 @@ def create_jwt(
     """
     if jwt is None:
         raise ImportError("JWT support is not installed.")
+
     secret = secret or get_config().secret_key
+    if expires_in and not payload.get("exp"):
+        payload["exp"] = datetime.now(timezone.utc) + expires_in
     return jwt.encode(payload, secret, algorithm=algorithm)  # type:ignore
 
 
@@ -51,8 +60,8 @@ def decode_jwt(
 
 
 class JWTAuthBackend(AuthenticationBackend):
-    def __init__(self, authenticate_func: Callable[[Dict[str, Any]], Any]):  # type:ignore
-        self.authenticate_func = authenticate_func
+    def __init__(self, identifier: str = "id"):  # type:ignore
+        self.identifier = identifier
 
     async def authenticate(self, request: Request, response: Response) -> Any:  # type:ignore
         app_config = get_config()
@@ -62,16 +71,14 @@ class JWTAuthBackend(AuthenticationBackend):
         auth_header = request.headers.get("Authorization")
         if not auth_header or not auth_header.startswith("Bearer "):
             response.set_header("WWW-Authenticate", 'Bearer realm="Access to the API"')
-            return None
+            return AuthResult(success=False, identity="", scope="")
 
         token = auth_header.split(" ")[1]
         try:
             payload = decode_jwt(token, self.secret, self.algorithms)
         except ValueError as _:
-            return None
+            return AuthResult(success=False, identity="", scope="")
 
-        user: Any = await self.authenticate_func(**payload)
-        if not user:
-            return UnauthenticatedUser()
-
-        return user, "jwt"
+        return AuthResult(
+            success=True, identity=payload.get(self.identifier, ""), scope="jwt"
+        )
