@@ -178,29 +178,30 @@ class BaseResponse:
             cache_control.append("public")
 
         cache_control.append(f"max-age={max_age}")
-        self.headers["cache-control"] = ", ".join(cache_control)
+        self.set_header("cache-control", ", ".join(cache_control))
 
         etag = self._generate_etag()
-        self.headers["etag"] = etag
+        self.set_header("etag", etag)
 
-        expires = datetime.utcnow() + timedelta(seconds=max_age)  # type: ignore
-        self.headers["expires"] = formatdate(expires.timestamp(), usegmt=True)
+        expires = datetime.now(timezone.utc) + timedelta(seconds=max_age)
+        self.set_header("expires", formatdate(expires.timestamp(), usegmt=True))
 
     def disable_caching(self) -> None:
         """Disable caching for this response."""
-        self.headers["cache-control"] = "no-store, no-cache, must-revalidate, max-age=0"
-        self.headers["pragma"] = "no-cache"
-        self.headers["expires"] = "0"
+        self.set_header(
+            "cache-control", "no-store, no-cache, must-revalidate, max-age=0"
+        )
+        self.set_header("pragma", "no-cache")
+        self.set_header("expires", "0")
 
     async def __call__(self, scope: Scope, receive: Receive, send: Send) -> None:
         """Make the response callable as an ASGI application."""
         self._init_headers()
-
         await send(
             {
                 "type": "http.response.start",
                 "status": self.status_code,
-                "headers": self._headers,
+                "headers": self._headers + scope.get("pre-response-headers", []),
             }
         )
 
@@ -241,6 +242,18 @@ class BaseResponse:
         self._headers.append(new_header)
         return self
 
+    def set_headers(self, headers: Dict[str, str], overide_all: bool = False):
+        if overide_all:
+            self._headers = [
+                (k.lower().encode("latin-1"), v.encode("latin-1"))
+                for k, v in headers.items()
+            ]
+            return
+        """Set multiple headers at once."""
+        for key, value in headers.items():
+            self.set_header(key, value)
+        return self
+
 
 class PlainTextResponse(BaseResponse):
     def __init__(
@@ -380,7 +393,7 @@ class FileResponse(BaseResponse):
             for range_str in ranges.split(","):
                 range = range_str.split("-")
                 start: int = int(range[0])
-                end: int = int(range[-1]) if range[-1] != "" else 0
+                end: int = int(range[-1]) if range[-1] != "" else 0  # type: ignore
                 start = int(start) if start else 0
                 end: int = int(end) if end else file_size - 1
 
@@ -577,6 +590,7 @@ class StreamingResponse(BaseResponse):
         async for chunk in self.content_iterator:
             if not isinstance(chunk, (bytes, memoryview)):
                 chunk = chunk.encode(self.charset)  # type:ignore
+
             await send({"type": "http.response.body", "body": chunk, "more_body": True})
 
         await send({"type": "http.response.body", "body": b"", "more_body": False})
@@ -881,6 +895,7 @@ class NexiosResponse:
 
     def set_headers(self, headers: Dict[str, str], overide_all: bool = False):
         if overide_all:
+            self._response.set_headers(headers)
             self._response._headers = [  # type:ignore
                 (bytes(str(k), "utf-8"), bytes(str(v), "utf-8"))
                 for k, v in self.headers.items()
@@ -929,7 +944,7 @@ class NexiosResponse:
 
     def paginate(
         self,
-        items: List[Any],
+        objects: List[Any],
         strategy: Union[str, BasePaginationStrategy] = "page_number",
         data_handler: type[SyncListDataHandler] = SyncListDataHandler,
         **kwargs: Dict[str, Any],
@@ -938,7 +953,7 @@ class NexiosResponse:
         Paginate the response data.
 
         Args:
-            items: List of items to paginate
+            objects: List of items to paginate
             total_items: Total number of items (optional, defaults to len(items))
             strategy: Either a string ('page_number', 'limit_offset', 'cursor') or
                     a custom pagination strategy instance
@@ -954,7 +969,7 @@ class NexiosResponse:
             else:
                 raise ValueError(f"Unknown pagination strategy: {strategy}")
 
-        _data_handler = data_handler(items)
+        _data_handler = data_handler(objects)
         request = self._request  # You'll need to store the request in the response
 
         paginator = SyncPaginator(
@@ -969,7 +984,7 @@ class NexiosResponse:
 
     async def apaginate(
         self,
-        items: List[Any],
+        objects: List[Any],
         strategy: Union[str, BasePaginationStrategy] = "page_number",
         data_handler: type[AsyncListDataHandler] = AsyncListDataHandler,
         **kwargs: Dict[str, Any],
@@ -978,7 +993,7 @@ class NexiosResponse:
         Paginate the response data.
 
         Args:
-            items: List of items to paginate
+            objects: List of items to paginate
             total_items: Total number of items (optional, defaults to len(items))
             strategy: Either a string ('page_number', 'limit_offset', 'cursor') or
                     a custom pagination strategy instance
@@ -994,7 +1009,7 @@ class NexiosResponse:
             else:
                 raise ValueError(f"Unknown pagination strategy: {strategy}")
 
-        _data_handler = data_handler(items)
+        _data_handler = data_handler(objects)
         request = self._request  # You'll need to store the request in the response
 
         paginator = AsyncPaginator(
