@@ -11,11 +11,12 @@ from typing import (
     Callable,
     Dict,
     List,
+    Literal,
     Optional,
     Pattern,
+    Sequence,
     Type,
     Union,
-    Literal,
 )
 
 from pydantic import BaseModel
@@ -30,22 +31,23 @@ from nexios._internals._middleware import (
 )
 from nexios._internals._response_transformer import request_response
 from nexios._internals._route_builder import RouteBuilder
-from nexios.dependencies import inject_dependencies
+from nexios.dependencies import Depend, inject_dependencies
 from nexios.events import AsyncEventEmitter
 from nexios.exceptions import NotFoundException
 from nexios.http import Request, Response
 from nexios.http.response import JSONResponse
-from nexios.openapi import Parameter
+from nexios.openapi.models import Parameter, Path, Schema
 from nexios.structs import RouteParam, URLPath
 from nexios.types import ASGIApp, HandlerType, MiddlewareType, Receive, Scope, Send
 
 from ._utils import get_route_path
 from .base import BaseRoute, BaseRouter
+from .grouping import Group
 
 allowed_methods_default = ["get", "post", "delete", "put", "patch", "options"]
 
 
-class Routes(BaseRoute):
+class Route(BaseRoute):
     """
     Encapsulates all routing information for an API endpoint, including path handling,
     validation, OpenAPI documentation, and request processing.
@@ -141,12 +143,16 @@ class Routes(BaseRoute):
             ),
         ] = None,
         request_content_type: Annotated[
-            Literal["application/json", "multipart/form-data", "application/x-www-form-urlencoded"],
+            Literal[
+                "application/json",
+                "multipart/form-data",
+                "application/x-www-form-urlencoded",
+            ],
             Doc(
                 "Content type for the request body in OpenAPI docs. Defaults to 'application/json'."
             ),
         ] = "application/json",
-        tags: Optional[List[str]] = None,
+        tags: Optional[Sequence[str]] = None,
         security: Optional[List[Dict[str, List[str]]]] = None,
         operation_id: Optional[str] = None,
         deprecated: bool = False,
@@ -225,7 +231,7 @@ class Routes(BaseRoute):
             return match, matched_params, is_method_allowed
         return None, None, False
 
-    def url_path_for(self, _name: str, **path_params: Any) -> URLPath:
+    def url_path_for(self, _name: str, **path_params: Dict[str, Any]) -> URLPath:
         """
         Generate a URL path for the route with the given name and parameters.
 
@@ -261,7 +267,7 @@ class Routes(BaseRoute):
 
         return URLPath(path=path, protocol="http")
 
-    async def handle(self, scope: Scope, receive: Receive, send: Send) -> Any:
+    async def handle(self, scope: Scope, receive: Receive, send: Send) -> None:
         """
         Process an incoming request using the route's handler.
 
@@ -299,23 +305,24 @@ class Router(BaseRouter):
     def __init__(
         self,
         prefix: Optional[str] = None,
-        routes: Optional[List[Union[Routes, type[BaseRoute]]]] = None,
-        tags: Optional[List[str]] = None,
+        routes: Optional[Sequence[Union[Route, type[BaseRoute]]]] = None,
+        tags: Optional[Sequence[str]] = None,
         exclude_from_schema: bool = False,
         name: Optional[str] = None,
-        dependencies: Optional[list] = None,
+        dependencies: Optional[list[Depend]] = None,
     ):
         self.prefix = prefix or ""
         self.prefix.rstrip("/")
-        self.routes = []
+        self.routes = list(routes or [])
         self.middleware: typing.List[Middleware] = []
         self.sub_routers: Dict[str, Union[Router, ASGIApp]] = {}
-        self.route_class = Routes
+        self.route_class = Route
         self.tags = tags or []
         self.exclude_from_schema = exclude_from_schema
         self.name = name
         self.event = AsyncEventEmitter()
         self.dependencies = dependencies or []
+        self.root_path = ""
 
         if self.prefix and not self.prefix.startswith("/"):
             warnings.warn("Router prefix should start with '/'")
@@ -335,6 +342,7 @@ class Router(BaseRouter):
         Returns:
             ASGIApp: The application wrapped with all middleware.
         """
+
         for cls, args, kwargs in reversed(self.middleware):
             app = cls(app, *args, **kwargs)
         return app
@@ -342,8 +350,8 @@ class Router(BaseRouter):
     def add_route(
         self,
         route: Annotated[
-            Optional[Union[Routes, type[BaseRoute]]],
-            Doc("An instance of the Routes class representing an HTTP route."),
+            Optional[Union[Route, type[BaseRoute]]],
+            Doc("An instance of the Route class representing an HTTP route."),
         ] = None,
         path: Annotated[
             Optional[str],
@@ -427,8 +435,14 @@ class Router(BaseRouter):
             ),
         ] = None,
         request_content_type: Annotated[
-            Literal["application/json", "multipart/form-data", "application/x-www-form-urlencoded"],
-            Doc("Content type for the request body in OpenAPI docs. Defaults to 'application/json'."),
+            Literal[
+                "application/json",
+                "multipart/form-data",
+                "application/x-www-form-urlencoded",
+            ],
+            Doc(
+                "Content type for the request body in OpenAPI docs. Defaults to 'application/json'."
+            ),
         ] = "application/json",
         middleware: Annotated[
             List[Any],
@@ -509,14 +523,14 @@ class Router(BaseRouter):
         This method registers an HTTP route, allowing the application to handle requests for a specific URL path.
 
         Args:
-            route (Routes): The HTTP route configuration.
+            route (Route): The HTTP route configuration.
 
         Returns:
             None
 
         Example:
             ```python
-            route = Routes("/home", home_handler, methods=["GET", "POST"])
+            route = Route("/home", home_handler, methods=["GET", "POST"])
             app.add_route(route)
             ```
         """
@@ -525,7 +539,7 @@ class Router(BaseRouter):
                 raise ValueError(
                     "path and handler are required if route is not provided"
                 )
-            route = Routes(
+            route = Route(
                 path=path,
                 handler=handler,
                 methods=methods,
@@ -545,12 +559,11 @@ class Router(BaseRouter):
                 **kwargs,
             )
 
-        if not isinstance(route, Routes):
+        if not isinstance(route, Route):
             self.routes.append(route)
             return
 
-        route.tags = self.tags + route.tags if route.tags else self.tags
-        # original_handler = route.handler
+        route.tags = list(self.tags).extend(route.tags) if route.tags else self.tags
         if self.exclude_from_schema:
             route.exclude_from_schema = True
         original_handler = route.handler
@@ -574,8 +587,22 @@ class Router(BaseRouter):
             return await original_handler(*handler_args, **handler_kwargs)
 
         route.handler = wrapped_handler
-
         self.routes.append(route)
+        if getattr(route, "exclude_from_schema", False):
+            return
+        for method in route.methods:
+            parameters = [
+                Path(name=x, schema=Schema(type="string"), schema_=None)  # type: ignore
+                for x in route.param_names
+            ]
+            parameters.extend(route.parameters)  #  type: ignore
+            # Construct full path including router prefix and root_path
+            full_path = (
+                self.prefix
+                + self.root_path
+                + re.sub(r"\{(\w+):\w+\}", r"{\1}", route.raw_path)
+            )
+            
 
     def add_middleware(self, middleware: MiddlewareType) -> None:
         """Add middleware to the router"""
@@ -785,6 +812,7 @@ class Router(BaseRouter):
                 description=description,
                 responses=responses,
                 request_model=request_model,
+                request_content_type="application/json",
                 middleware=middleware,
                 tags=tags,
                 security=security,
@@ -878,8 +906,14 @@ class Router(BaseRouter):
             ),
         ] = None,
         request_content_type: Annotated[
-            Literal["application/json", "multipart/form-data", "application/x-www-form-urlencoded"],
-            Doc("Content type for the request body in OpenAPI docs. Defaults to 'application/json'."),
+            Literal[
+                "application/json",
+                "multipart/form-data",
+                "application/x-www-form-urlencoded",
+            ],
+            Doc(
+                "Content type for the request body in OpenAPI docs. Defaults to 'application/json'."
+            ),
         ] = "application/json",
         middleware: Annotated[
             List[Any],
@@ -1192,6 +1226,7 @@ class Router(BaseRouter):
             description=description,
             responses=responses,
             request_model=request_model,
+            request_content_type="application/json",
             middleware=middleware,
             tags=tags,
             security=security,
@@ -1341,7 +1376,11 @@ class Router(BaseRouter):
             ),
         ] = False,
         request_content_type: Annotated[
-            Optional[Literal["application/json", "application/x-www-form-urlencoded", "multipart/form-data"]],
+            Literal[
+                "application/json",
+                "application/x-www-form-urlencoded",
+                "multipart/form-data",
+            ],
             Doc(
                 """
                 Request content type.
@@ -1553,7 +1592,11 @@ class Router(BaseRouter):
             ),
         ] = False,
         request_content_type: Annotated[
-            Optional[Literal["application/json", "application/x-www-form-urlencoded", "multipart/form-data"]],
+            Literal[
+                "application/json",
+                "application/x-www-form-urlencoded",
+                "multipart/form-data",
+            ],
             Doc(
                 """
                 Request content type.
@@ -1808,6 +1851,7 @@ class Router(BaseRouter):
             description=description,
             responses=responses,
             request_model=request_model,
+            request_content_type="application/json",
             middleware=middleware,
             tags=tags,
             security=security,
@@ -2001,6 +2045,7 @@ class Router(BaseRouter):
             description=description,
             responses=responses,
             request_model=request_model,
+            request_content_type="application/json",
             middleware=middleware,
             tags=tags,
             security=security,
@@ -2074,6 +2119,16 @@ class Router(BaseRouter):
             Optional[Type[BaseModel]],
             Doc("Pydantic model for request body validation and OpenAPI docs"),
         ] = None,
+        request_content_type: Annotated[
+            Literal[
+                "application/json",
+                "multipart/form-data",
+                "application/x-www-form-urlencoded",
+            ],
+            Doc(
+                "Content type for the request body in OpenAPI docs. Defaults to 'application/json'."
+            ),
+        ] = "application/json",
         middleware: Annotated[
             List[MiddlewareType],
             Doc(
@@ -2187,6 +2242,7 @@ class Router(BaseRouter):
                 description=description,
                 responses=responses,
                 request_model=request_model,
+                request_content_type=request_content_type,
                 middleware=middleware,
                 tags=tags,
                 security=security,
@@ -2215,33 +2271,81 @@ class Router(BaseRouter):
             URLPath: Complete path including all router prefixes
         """
         name_parts = _name.split(".")
-        current_router = self
-        path_segments = []
 
-        # First collect all router prefixes
-        for part in name_parts[:-1]:
-            found = False
-            for mount_path, sub_router in current_router.sub_routers.items():
-                if getattr(sub_router, "name", None) == part:
-                    path_segments.append(mount_path.strip("/"))
-                    current_router = sub_router
-                    found = True
-                    break
-            if not found:
-                raise ValueError(
-                    f"Router '{part}' not found while building URL for '{_name}'"
-                )
+        # If it's a simple route name (no dots), search directly in current routes
+        if len(name_parts) == 1:
+            route_name = name_parts[0]
+            for route in self.routes:
+                if getattr(route, "name", None) == route_name:
+                    route_path = route.url_path_for(_name=route_name, **path_params)
+                    return URLPath(path=str(route_path), protocol="http")
+            raise ValueError(f"Route '{route_name}' not found in router")
 
-        route_name = name_parts[-1]
-        for route in current_router.routes:
-            if route.name == route_name:
-                route_path = route.url_path_for(route_name, **path_params)
-                path_segments.append(route_path.strip("/"))
+        # For nested routes, recursively search through Group objects
+        return self._search_nested_route(_name, name_parts, [], **path_params)
 
-                full_path = "/" + "/".join(filter(None, path_segments))
-                return URLPath(path=full_path, protocol="http")
+    def _search_nested_route(
+        self,
+        full_name: str,
+        name_parts: List[str],
+        path_segments: List[str],
+        **path_params: Any,
+    ) -> URLPath:
+        """
+        Recursively search for a route in nested Group objects.
 
-        raise ValueError(f"Route '{route_name}' not found in router")
+        Args:
+            full_name: The original full route name for error messages
+            name_parts: Remaining parts of the route name to resolve
+            path_segments: Accumulated path segments from parent routers
+            **path_params: Path parameters to substitute
+
+        Returns:
+            URLPath: Complete path including all router prefixes
+        """
+        if not name_parts:
+            raise ValueError(f"Invalid route name format: '{full_name}'")
+
+        current_part = name_parts[0]
+        remaining_parts = name_parts[1:]
+
+        # If this is the last part, it's the route name
+        if len(remaining_parts) == 0:
+            for route in self.routes:
+                if getattr(route, "name", None) == current_part:
+                    route_path = route.url_path_for(_name=current_part, **path_params)
+                    path_segments.append(str(route_path).strip("/"))
+                    full_path = "/" + "/".join(filter(None, path_segments))
+                    return URLPath(path=full_path, protocol="http")
+            raise ValueError(f"Route '{current_part}' not found in router")
+
+        # Look for a Group with the current part as name
+        for route in self.routes:
+            if (
+                isinstance(route, Group)
+                and getattr(route, "name", None) == current_part
+            ):
+                # Add this Group's path to segments
+                group_path = route.path.strip("/")
+                if group_path:
+                    new_path_segments = path_segments + [group_path]
+                else:
+                    new_path_segments = path_segments
+
+                # Get the underlying router from the Group
+                underlying_router = getattr(route, "_base_app", None)
+                if isinstance(underlying_router, Router):
+                    return underlying_router._search_nested_route(
+                        full_name, remaining_parts, new_path_segments, **path_params
+                    )
+                else:
+                    raise ValueError(
+                        f"Group '{current_part}' does not contain a Router"
+                    )
+
+        raise ValueError(
+            f"Router '{current_part}' not found while building URL for '{full_name}'"
+        )
 
     def __repr__(self) -> str:
         return f"<Router prefix='{self.prefix}' routes={len(self.routes)}>"
@@ -2261,23 +2365,24 @@ class Router(BaseRouter):
 
         for mount_path, sub_app in self.sub_routers.items():
             if url.startswith(mount_path):
-                scope["path"] = url[len(mount_path) :]
+                # scope["path"] = url[len(mount_path) :]
+                # scope["root_path"] = scope.get("root_path", "") + mount_path
                 await sub_app(scope, receive, send)
 
                 return
 
         path_matched = False
-        allowed_methods_: typing.Set[str] = set()
+        allowed_methods_: typing.List[str] = []
         for route in self.routes:
-            match, matched_params, is_allowed = route.match(url, scope["method"])
+            match, matched_params, is_allowed = route.match(url, scope["method"])  # type:ignore
             if match:
                 path_matched = True
                 if is_allowed:
                     scope["route_params"] = RouteParam(matched_params)
-                    await route.handle(scope, receive, send)
+                    await route.handle(scope, receive, send)  # type:ignore
                     return
                 else:
-                    allowed_methods_.update(route.methods)
+                    allowed_methods_.extend(route.methods)  # type:ignore
         if path_matched:
             response = JSONResponse(
                 content="Method not allowed",
@@ -2289,33 +2394,19 @@ class Router(BaseRouter):
 
         raise NotFoundException
 
-    def mount_router(self, app: "Router", path: typing.Optional[str] = None) -> None:
+    def mount_router(self, app: "Router", name: Optional[str] = None):
         """
-        Mount an ASGI application (e.g., another Router) under a specific path prefix.
+        Mount an ASGI application (e.g., another Router) using its prefix.
 
         Args:
-            path: The path prefix under which the app will be mounted.
             app: The ASGI application (e.g., another Router) to mount.
         """
+        path = app.prefix
+        self.routes.append(Group(app=app, path=path, name=name))
 
-        if not path:
-            path = app.prefix
-        path = path.rstrip("/")
-
-        if path == "":
-            self.sub_routers[path] = app
-            return
-        if not path.startswith("/"):
-            path = f"/{path}"
-
-        if path in self.sub_routers.keys():
-            raise ValueError("Router with prefix exists !")
-
-        self.sub_routers[path] = app
-
-    def get_all_routes(self) -> List[Routes]:
+    def get_all_routes(self) -> List[Route]:
         """Returns a flat list of all HTTP routes in this router and all nested sub-routers"""
-        all_routes: List[Routes] = []
+        all_routes: List[Route] = []
         routers_to_process: List[Any] = [(self, "")]  # (router, current_prefix)
 
         while routers_to_process:
@@ -2348,4 +2439,6 @@ class Router(BaseRouter):
             prefix: The path prefix under which the app will be registered.
         """
 
-        self.sub_routers[prefix] = app
+        self.add_route(Group(app=app, path=prefix))
+
+Routes = Route #for backward compatibilty 
\ No newline at end of file
