@@ -1,11 +1,11 @@
-from nexios import get_application
-from nexios.routing import Routes
-
 from config import app_config
 from routes.index import index
 
+from nexios import NexiosApp
+from nexios.routing import Route
+
 # Create the application
-app = get_application(title="{{project_name_title}}", config=app_config)
+app = NexiosApp(title="{{project_name_title}}", config=app_config)
 
 
 @app.on_startup
@@ -21,5 +21,5 @@ async def shutdown():
 
 
 app.add_route(
-    Routes("/", index, summary="Homepage route", description="Homepage route"),
+    Route("/", index, summary="Homepage route", description="Homepage route"),
 )
