@@ -2,7 +2,7 @@ import logging
 from typing import Any, Callable, Coroutine, Dict, List, Optional, Type
 
 from nexios.http import Request, Response
-from nexios.routing import Routes as Route
+from nexios.routing import Route as Route
 from nexios.types import MiddlewareType
 
 logger = logging.getLogger(__name__)
@@ -22,7 +22,7 @@ class APIView:
 
     @classmethod
     def as_route(
-        cls, path: str, methods: Optional[List[str]] = None, **kwargs
+        cls, path: str, methods: Optional[List[str]] = None, **kwargs: Dict[str, Any]
     ) -> Route:
         """
         Convert the APIView class into a Route that can be registered with the app or router.
@@ -34,15 +34,23 @@ class APIView:
                 if name in cls.__dict__
             ]
 
-        async def handler(req: Request, res: Response, **kwargs) -> Response:
+        async def handler(
+            req: Request, res: Response, **kwargs: Dict[str, Any]
+        ) -> Response:
             instance = cls()
             return await instance.dispatch(req, res, **kwargs)
 
         return Route(
-            path, handler, methods=methods, middleware=cls.middleware, **kwargs
+            path,
+            handler,
+            methods=methods,
+            middleware=cls.middleware,
+            **kwargs,  #  type: ignore
         )
 
-    async def dispatch(self, req: Request, res: Response, **kwargs) -> Response:
+    async def dispatch(
+        self, req: Request, res: Response, **kwargs: Dict[str, Any]
+    ) -> Response:
         """
         Dispatch the request to the appropriate handler method.
         """
@@ -59,9 +67,7 @@ class APIView:
                     return await handler(req, res, e)
             raise e
 
-    async def method_not_allowed(
-        self, req: Request, res: Response, **kwargs
-    ) -> Response:
+    async def method_not_allowed(self, req: Request, res: Response) -> Response:
         """
         Handle requests with unsupported HTTP methods.
         """
